@@ -17,7 +17,7 @@ class SSHD(Traceback):
 
 		# check downloads.
 		if CHECKS:
-			response = self.__install_utils__(usernames=[Defaults.vars.user])
+			response = self.__install_utils__(usernames=[dev0s.defaults.vars.user])
 			if not response.success: response.crash()
 
 	def create(self,
@@ -197,10 +197,10 @@ class SSHD(Traceback):
 			fp.ownership.set(owner="root", group=None, sudo=True)
 			os.system("sudo systemctl restart ssh")
 			if not fp.exists(sudo=True):
-				return Response.error(f"Failed to save the sshd configuration.")
+				return dev0s.response.error(f"Failed to save the sshd configuration.")
 
 		# success.
-		return Response.success("Successfully created the sshd configuration.", {
+		return dev0s.response.success("Successfully created the sshd configuration.", {
 				"sshd":configuration,
 			})
 
@@ -228,7 +228,7 @@ class SSHD(Traceback):
 			try: 
 				info["allowed_ips"]
 				if not isinstance(info["allowed_ips"], list):
-					return Response.error(f"Invalid usage, parameter [users.{username}.allowed_ips] is supposed to be a list with allowed ip addresses.")
+					return dev0s.response.error(f"Invalid usage, parameter [users.{username}.allowed_ips] is supposed to be a list with allowed ip addresses.")
 			except KeyError: info["allowed_ips"] = []
 			try: info["sftp_only"]
 			except KeyError: info["sftp_only"] = False
@@ -240,7 +240,7 @@ class SSHD(Traceback):
 			except KeyError: info["tcp_forwarding"] = False
 
 		# response.
-		return Response.success("Successfully checked the user items.")
+		return dev0s.response.success("Successfully checked the user items.")
 
 		#
 	def __check_utils_installed__(self, usernames=[]):
@@ -251,7 +251,7 @@ class SSHD(Traceback):
 		for username in usernames:
 			
 			# non existant.
-			fp = FilePath(f"{Defaults.vars.homes}{username}/.ssht00ls/utils/.version")
+			fp = FilePath(f"{dev0s.defaults.vars.homes}{username}/.ssht00ls/utils/.version")
 			if not fp.exists(sudo=True): 
 				to_install.append(username)
 
@@ -268,7 +268,7 @@ class SSHD(Traceback):
 			if response["error"] != None: return response
 
 		# success.
-		return Response.success("Successfully verified the ssht00ls utils installation.")
+		return dev0s.response.success("Successfully verified the ssht00ls utils installation.")
 
 		#
 	def __install_utils__(self, usernames=[]):
@@ -276,7 +276,7 @@ class SSHD(Traceback):
 		# checks.
 		if isinstance(usernames, str): usernames = [usernames]
 		if len(usernames) == 0: 
-			return Response.error("No usernames specified.")
+			return dev0s.response.error("No usernames specified.")
 
 		# create tmp lib.
 		utils_lib = gfp.clean(path=f"{SOURCE_PATH}/lib/utils/")
@@ -295,7 +295,7 @@ class SSHD(Traceback):
 				if response["error"] != None: return response
 
 			# copy.
-			fp = FilePath(f"{Defaults.vars.homes}{username}/.ssht00ls/utils/")
+			fp = FilePath(f"{dev0s.defaults.vars.homes}{username}/.ssht00ls/utils/")
 			if not Files.exists(fp.base(), sudo=True):
 				Files.create(path=fp.base(), sudo=True, directory=True)
 			fp.delete(sudo=True, forced=True)
@@ -303,10 +303,10 @@ class SSHD(Traceback):
 			fp.ownership.set(owner=username, group=None, sudo=True, recursive=True)
 			fp.permission.set(permission=755, recursive=True, sudo=True)
 			if not fp.exists(sudo=True):
-				return Response.error("Failed to install the ssht00ls utils (#3).")
+				return dev0s.response.error("Failed to install the ssht00ls utils (#3).")
 
 		# success.
-		return Response.success("Successfully installed the ssht00ls utils.")
+		return dev0s.response.success("Successfully installed the ssht00ls utils.")
 
 		#
 	def __install_banner__(self, banner="", usernames=[]):
@@ -314,7 +314,7 @@ class SSHD(Traceback):
 		# checks.
 		if isinstance(usernames, str): usernames = [usernames]
 		if len(usernames) == 0: 
-			return Response.error("No usernames specified.")
+			return dev0s.response.error("No usernames specified.")
 
 		# save banner.
 		file = File(path='/tmp/banner', data=banner)
@@ -323,15 +323,15 @@ class SSHD(Traceback):
 
 		# iterate.
 		for username in usernames:
-			fp = FilePath(f"/{Defaults.vars.homes}{username}/.ssh/banner")
+			fp = FilePath(f"/{dev0s.defaults.vars.homes}{username}/.ssh/banner")
 			file.file_path.copy(fp.path, sudo=True)
 			fp.permission.set(permission=755, sudo=True)
 			fp.ownership.set(owner=username, group=None, sudo=True)
 			if not fp.exists(sudo=True):
-				return Response.error(f"Failed to install the banner for user [{username}].")
+				return dev0s.response.error(f"Failed to install the banner for user [{username}].")
 
 		# success.
-		return Response.success("Successfully installed the banner.")
+		return dev0s.response.success("Successfully installed the banner.")
 
 		#
 	#
