@@ -30,7 +30,7 @@ class SSync(Traceback):
 		self.daemons = daemons
 		
 		#
-	def index(self, path=None, alias=None, log_level=Defaults.options.log_level, checks=True, accept_new_host_keys=True):
+	def index(self, path=None, alias=None, log_level=dev0s.defaults.options.log_level, checks=True, accept_new_host_keys=True):
 
 		# check specific.
 		if self.specific:
@@ -38,12 +38,12 @@ class SSync(Traceback):
 
 		# checks.
 		if path == None:
-			return Response.error(f"Define parameter: path.")
+			return dev0s.response.error(f"Define parameter: path.")
 		path = gfp.clean(path)
 
 		# check encryption activated.
 		if not ssht00ls_agent.activated:
-			return Response.error(f"The {ssht00ls_agent.id} encryption requires to be activated.")
+			return dev0s.response.error(f"The {ssht00ls_agent.id} encryption requires to be activated.")
 
 		# remote.
 		if alias != None:
@@ -57,12 +57,16 @@ class SSync(Traceback):
 
 				# check passphrase.
 				if CONFIG["aliases"][alias]["smartcard"] in [True, "true", "True"]:
-					response = ssht00ls_agent.encryption.decrypt(CONFIG["aliases"][alias]["passphrase"])
+					passphrase = CONFIG["aliases"][alias]["pin"]
 				else:
-					response = ssht00ls_agent.encryption.decrypt(CONFIG["aliases"][alias]["passphrase"])
-				if not response["success"]: return response
-				passphrase = response.decrypted.decode()
-				
+					passphrase = CONFIG["aliases"][alias]["passphrase"]
+				if passphrase not in ["", "none", "None", None]:
+					response = ssht00ls_agent.encryption.decrypt()
+					if not response["success"]: return response
+					passphrase = response.decrypted.decode()
+				else:
+					passphrase = None
+					
 				# tests.
 				response = agent.add(private_key=CONFIG["aliases"][alias]["private_key"], passphrase=passphrase)
 				if not response["success"]: return response
@@ -81,7 +85,7 @@ class SSync(Traceback):
 				},
 				optional=True,)
 			if not response.success:
-				return Response.error(f"Failed to connect with {alias}, error: {response.error}")
+				return dev0s.response.error(f"Failed to connect with {alias}, error: {response.error}")
 			else:
 				return response
 
@@ -89,19 +93,19 @@ class SSync(Traceback):
 		else:
 			if checks:
 				if not Files.exists(path):
-					return Response.error(f"Path [{path}] does not exist.")
+					return dev0s.response.error(f"Path [{path}] does not exist.")
 				elif not os.path.isdir(path):
-					return Response.error(f"Path [{path}] is not a directory.")
+					return dev0s.response.error(f"Path [{path}] is not a directory.")
 
 			# handler.
 			dict = self.utils.index(path)
-			return Response.success(f"Successfully indexed {len(dict)} files from directory [{path}].", {
+			return dev0s.response.success(f"Successfully indexed {len(dict)} files from directory [{path}].", {
 				"index":dict,
 			})
 
 			#
 	def set_mounted_icon(self, path):
-		if Defaults.vars.os in ["osx", "macos"]:
+		if dev0s.defaults.vars.os in ["osx", "macos"]:
 			#os.system(f"cp '{SOURCE_PATH}/static/media/icons/Icon\r' '{path}/Icon\r'")
 			icon = f'{SOURCE_PATH}/static/media/icons/mounted.png'
 			dev0s.utils.__execute_script__(f"""
@@ -175,7 +179,7 @@ class SSync(Traceback):
 		# checks.
 		checks=True,
 		# log level.
-		log_level=Defaults.options.log_level,
+		log_level=dev0s.defaults.options.log_level,
 		# get the command in str.
 		command=False,
 	):	
@@ -186,7 +190,7 @@ class SSync(Traceback):
 
 		# check encryption activated.
 		if not ssht00ls_agent.activated:
-			return Response.error(f"The {ssht00ls_agent.id} encryption requires to be activated.")
+			return dev0s.response.error(f"The {ssht00ls_agent.id} encryption requires to be activated.")
 		if checks:
 			if self.specific:
 				try: self.activated
@@ -199,11 +203,15 @@ class SSync(Traceback):
 					if "is not added to the" not in response.error: return response
 					else:
 						if CONFIG["aliases"][alias]["smartcard"] in [True, "true", "True"]:
-							response = ssht00ls_agent.encryption.decrypt(CONFIG["aliases"][alias]["passphrase"])
+							passphrase = CONFIG["aliases"][alias]["pin"]
 						else:
-							response = ssht00ls_agent.encryption.decrypt(CONFIG["aliases"][alias]["passphrase"])
-						if not response["success"]: return response
-						passphrase = response.decrypted.decode()
+							passphrase = CONFIG["aliases"][alias]["passphrase"]
+						if passphrase not in [None, "None", "none", "", False]:
+							response = ssht00ls_agent.encryption.decrypt(passphrase)
+							if not response["success"]: return response
+							passphrase = response.decrypted.decode()
+						else:
+							passphrase = None
 						response = agent.add(private_key=CONFIG["aliases"][alias]["private_key"], passphrase=passphrase)
 						if not response["success"]: return response
 				if self.specific: self.activated = True
@@ -257,7 +265,7 @@ class SSync(Traceback):
 		checks=True,
 		check_base=True,
 		# log level.
-		log_level=Defaults.options.log_level,
+		log_level=dev0s.defaults.options.log_level,
 		# get the command in str.
 		command=False,
 	):
@@ -268,7 +276,7 @@ class SSync(Traceback):
 
 		# check encryption activated.
 		if not ssht00ls_agent.activated:
-			return Response.error(f"The {ssht00ls_agent.id} encryption requires to be activated.")
+			return dev0s.response.error(f"The {ssht00ls_agent.id} encryption requires to be activated.")
 		if checks:
 			if self.specific:
 				try: self.activated
@@ -281,16 +289,15 @@ class SSync(Traceback):
 					if "is not added to the" not in response.error: return response
 					else:
 						if CONFIG["aliases"][alias]["smartcard"] in [True, "true", "True"]:
-							response = ssht00ls_agent.encryption.decrypt(CONFIG["aliases"][alias]["pin"])
+							passphrase = CONFIG["aliases"][alias]["pin"]
+						else:
+							passphrase = CONFIG["aliases"][alias]["passphrase"]
+						if passphrase not in [None, "None", "none", "", False]:
+							response = ssht00ls_agent.encryption.decrypt(passphrase)
 							if not response["success"]: return response
 							passphrase = response.decrypted.decode()
 						else:
-							if CONFIG["aliases"][alias]["passphrase"] not in ["", False]:
-								response = ssht00ls_agent.encryption.decrypt(CONFIG["aliases"][alias]["passphrase"])
-								if not response["success"]: return response
-								passphrase = response.decrypted.decode()
-							else:
-								passphrase = None
+							passphrase = None
 						response = agent.add(private_key=CONFIG["aliases"][alias]["private_key"], passphrase=passphrase)
 						if not response["success"]: return response
 				if self.specific: self.activated = True
@@ -336,20 +343,20 @@ class SSync(Traceback):
 		# accept new host verification keys.
 		accept_new_host_keys=True,
 		# log level.
-		log_level=Defaults.options.log_level,
+		log_level=dev0s.defaults.options.log_level,
 		# the daemon mode.
 		mode="mount",
 	):
 
 		# depricated.
-		return Response.error("DEPRICATED.")
+		return dev0s.response.error("DEPRICATED.")
 		
 		# check specific.
 		if self.specific:
 			if alias == None: alias = self.alias
 
 		# checks.
-		response = Response.parameters.check(
+		response = dev0s.response.parameters.check(
 			traceback=self.__traceback__(function="mount"), 
 			parameters={
 				"path:str":path,
@@ -363,12 +370,12 @@ class SSync(Traceback):
 		if not response["success"]: return response
 		if mode in ["synchronize", "sync", "synch"]: mode = "sync"
 		if mode not in ["mount", "sync"]:
-			return Response.error(f"Specified an invalid mode: [{mode}], options: [mount, sync].")
+			return dev0s.response.error(f"Specified an invalid mode: [{mode}], options: [mount, sync].")
 		cache_path = gfp.absolute(path=gfp.clean(path.split(" (d)")[0], remove_last_slash=True))
 		if mode in ["mount"] and not forced and Files.exists(path):
-			return Response.error(f"Path [{path}] already exists.")
+			return dev0s.response.error(f"Path [{path}] already exists.")
 		elif self.daemons.running(cache_path):
-			return Response.error(f"Path [{path}] is already mounted.")
+			return dev0s.response.error(f"Path [{path}] is already mounted.")
 		path = gfp.clean(path=path)
 		remote = gfp.clean(path=remote)
 
@@ -395,29 +402,29 @@ class SSync(Traceback):
 				else:
 					return response
 			if not remote_exists and not local_exists:
-				return Response.error(f"Both local and remote directories {path} & {alias}:{remote} do not exist.")
+				return dev0s.response.error(f"Both local and remote directories {path} & {alias}:{remote} do not exist.")
 			if not local_exists:
 				os.system(f"mkdir -p {path}")
 				if not Files.exists(path): 
-					return Response.error(f"Failed to create directory {path}.")
+					return dev0s.response.error(f"Failed to create directory {path}.")
 			if not remote_exists:
 				response = ssh.utils.test_dir(path=remote, alias=alias, create=True)
 				if not response["success"]: 
-					return Response.error(f"Failed to create directory {alias}:{remote}, error: {response['error']}")
+					return dev0s.response.error(f"Failed to create directory {alias}:{remote}, error: {response['error']}")
 
 		# start daemon.
 		cache.set(id=cache_path, group="daemons", data=f"*running* (timestamp={Date().seconds_timestamp})")
 		self.set_mounted_icon(path)
 		if not self.daemons.running(cache_path):
-			return Response.error(f"Failed to set the {path} daemon status.")
+			return dev0s.response.error(f"Failed to set the {path} daemon status.")
 		response =  self.daemon(alias=alias, path=path, remote=remote, start=True, mode=mode)
 		if not response.success: return response
 
 		# handler.
 		if mode == "sync":
-			return Response.success(f"Successfully synchronized {alias}:{remote} to {path}.")
+			return dev0s.response.success(f"Successfully synchronized {alias}:{remote} to {path}.")
 		else:
-			return Response.success(f"Successfully mounted {alias}:{remote} to {path}.")
+			return dev0s.response.success(f"Successfully mounted {alias}:{remote} to {path}.")
 
 		#
 	def unmount(self, 
@@ -428,14 +435,14 @@ class SSync(Traceback):
 		# sudo required.
 		sudo=False,
 		# log level.
-		log_level=Defaults.options.log_level,
+		log_level=dev0s.defaults.options.log_level,
 	):
 
 		# depricated.
-		return Response.error("DEPRICATED.")
+		return dev0s.response.error("DEPRICATED.")
 
 		# checks.
-		response = Response.parameters.check(
+		response = dev0s.response.parameters.check(
 			traceback=self.__traceback__(function="unmount"), 
 			parameters={
 				"path:str":path,
@@ -447,19 +454,19 @@ class SSync(Traceback):
 		cache_path = gfp.absolute(gfp.clean(path.split(" (d)")[0], remove_last_slash=True))
 		if not self.daemons.running(cache_path):
 			if not Files.exists(path):
-				return Response.error(f"Path [{path}] does not exist.")
+				return dev0s.response.error(f"Path [{path}] does not exist.")
 			elif not os.path.isdir(path):
-				return Response.error(f"Path [{path}] is not a directory.")
+				return dev0s.response.error(f"Path [{path}] is not a directory.")
 			status = str(cache.get(id=cache_path, group="daemons"))
 			if not self.daemons.running(cache_path):
-				return Response.error(f"Path [{path}] is not mounted (status: {status}).")
+				return dev0s.response.error(f"Path [{path}] is not mounted (status: {status}).")
 
 		# wait for daemon stop.
 		response = self.daemons.stop(path=path)
 		if not success: return response
 
 		# handler.
-		return Response.success(f"Successfully unmounted [{path}].")
+		return dev0s.response.success(f"Successfully unmounted [{path}].")
 
 		#
 	def daemon(self, 
@@ -474,7 +481,7 @@ class SSync(Traceback):
 		# the daemon mode.
 		mode="mount",
 		# the daemons log level.
-		log_level=Defaults.log_level(default=-1),
+		log_level=dev0s.defaults.log_level(default=-1),
 		# sandbox (do not delete any files).
 		sandbox=False,
 		# overwrite sleeptime.
@@ -483,7 +490,7 @@ class SSync(Traceback):
 		serialized={},
 	):
 		# depricated.
-		return Response.error("DEPRICATED.")
+		return dev0s.response.error("DEPRICATED.")
 
 		# check specific.
 		if self.specific:
@@ -497,13 +504,13 @@ class SSync(Traceback):
 				"path":None,
 				"start":True,
 				"mode":"mount",
-				"log_level":Defaults.log_level(default=-1),
+				"log_level":dev0s.defaults.log_level(default=-1),
 				"sandbox":False,
 				"sleeptime":SSYNC_DAEMON_SLEEPTIME,
 			})
 		if mode in ["synchronize", "sync", "synch"]: mode = "sync"
 		if mode not in ["mount", "sync"]:
-			return Response.error(f"Specified an invalid mode: [{mode}], options: [mount, sync].")
+			return dev0s.response.error(f"Specified an invalid mode: [{mode}], options: [mount, sync].")
 		path = gfp.clean(path)
 		remote = gfp.clean(remote)
 		_daemon_ = daemons.Daemon({
@@ -518,12 +525,12 @@ class SSync(Traceback):
 			"sleeptime":sleeptime,
 		})
 		if start: ssht00ls_agent.webserver.start_thread(_daemon_, group="daemons", id=_daemon_.id)
-		return Response.success("Successfully initialized the daemon", {
+		return dev0s.response.success("Successfully initialized the daemon", {
 			"daemon":_daemon_,
 		})
 	
 # initialized objects.
 ssync = SSync()
-if CHECKS and INTERACTIVE and not CLI.argument_present("--reset-cache"):
+if CHECKS and dev0s.defaults.options.interactive and not dev0s.cli.argument_present("--reset-cache"):
 	daemons.sync()
 	
\ No newline at end of file
